package cueexperiment

import (
	"testing"

	"github.com/go-quicktest/qt"
)

func TestInit(t *testing.T) {
	// This is just a smoke test to make sure it's all wired up OK.
	t.Setenv("CUE_EXPERIMENT", "cmdreferencepkg=0,keepvalidators")
	err := Init()
	qt.Assert(t, qt.IsNil(err))
	qt.Assert(t, qt.IsFalse(Flags.CmdReferencePkg))
	qt.Assert(t, qt.IsTrue(Flags.KeepValidators))
}
